from icy.main import Icy
from icy.sequence import Sequence
from icy.sequence import SequenceDataIterator
from icy.image import ImageDataIterator
from icy.image import IcyBufferedImage
from icy.gui.viewer import Viewer
from icy.type import DataType
from java.util import NoSuchElementException

'''
Generate projection from ground truth ROIs.
'''

# Name of the ground truth 3D sequence.
seq3d_name = 'Live-Notum-2018_03_08_cad_cic_LSM-C0T0.tif'

method = 'mip' # 'mean'

main = Icy.getMainInterface()
seq = main.getSequences( seq3d_name ).get( 0 )

# Prepare target sequence.
width = seq.getWidth()
height = seq.getHeight()

img = IcyBufferedImage( width, height, 1, DataType.DOUBLE )
nImg = IcyBufferedImage( width, height, 1, DataType.INT )
heightMap = IcyBufferedImage( width, height, 1, DataType.FLOAT )

# Get ROIs.
all_rois = seq.getROIs();

rois = [ roi for roi in all_rois if roi.getName().startswith('z') ]

for roi in rois:
	z = roi.getZ();
	# Shift all Zs by 1, so that 0 labels portions of the image without tissue.
	z = z + 1
	it = SequenceDataIterator( seq, roi )
	while not it.done():
		it.next()
		x = it.getPositionX()
		y = it.getPositionY()
		try:
			# Accumulate.
			v1 = it.get()
			v2 = img.getData( x, y, 0 )

			# Number of ROIs for this X, Y location:	
			n1 = nImg.getData( x, y, 0 )		
			nImg.setData( x, y, 0, n1 + 1 )

			# Heigh map at this X, Y:
			z1 = heightMap.getData( x, y, 0 )
			heightMap.setData( x, y, 0, z + z1 )

			# How to deal with projection when we have more than 1 ROI?
			if method == 'mean':
				# Mean
				img.setData( x, y, 0, v1 + v2 )
			elif method == 'mip':
				# Max
				img.setData( x, y, 0, max( v1, v2 ) )
			

		except NoSuchElementException:
			print('Could not access pixel (%d,%d) for z = %d.' % (x, y, z ) )


# Compute a mean height map.
itHM = ImageDataIterator( heightMap )
while not itHM.done():
	itHM.next()
	x = itHM.getPositionX()
	y = itHM.getPositionY()
	if (x >= width ) or ( y >= height):
		continue

	try:
		n = nImg.getData( x, y, 0 )
		if n == 0:
			continue
		zSum = itHM.get()
		heightMap.setData( x, y, 0, zSum / n )
	except NoSuchElementException:
		print('Could not access heigh-map pixel (%d,%d)' % (x, y ) )


# Show height map.
sHeightMap = Sequence( heightMap )
sHeightMap.setName( 'Ground truth Height map' )
Viewer( sHeightMap )



# Projection 
if method == 'mean':
	# Compute mean.
	it2 = ImageDataIterator( img )
	while not it2.done():
		it2.next()
		x = it2.getPositionX()
		y = it2.getPositionY()
		if (x >= width ) or ( y >= height):
			continue
			
		try:
			n = nImg.getData( x, y, 0 )
			if n == 0:
				continue
			v = it2.get()
			img.setData( x, y, 0, v / n )
		except NoSuchElementException:
			print('Could not access pixel (%d,%d) for z = %d.' % (x, y, z ) )

# Show results.
s1 = Sequence( img )

if method == 'mean':
	name = 'Groundth truth by mean'
	s2 = Sequence( nImg )
	s2.setName( 'Planes accumulated' )
	Viewer( s2 )
elif method == 'mip':
	name = 'Groundth truth by MIP'

s1.setName( name )
Viewer( s1 )

