# Building the ground-truth files.

A ground-truth is required to measure the performance of various projection methods. 

We generate the ground-truth by manual annotation. Each slice of the 3D stack is manually annotated for regions where the cells of interest are in focus. A Jython script then parsed these regions to fetch the pixel in the specified Z-plane for each (X,Y) position, and writes its value on a single plane, generating the ground-truth for the projection. When a single (X,Y) position was represented by several regions in different Z planes, the pixel with the maximal value was retained. 

The height-map image corresponding to this projection was generated along, by simply writing the Z position retained for projection as pixel value. When a (X,Y) position was represented by several regions in different Z planes, the height-map value was taken as the mean of all the Z "in-focus" positions. This led to the height-map ground-truth image having non-integer values for some pixels. 

As noted in our article, the metric values we get might be affected by the imprecision of manual annotation. We nonetheless use the RMSE defined above to rank each method and detect projection defects, keeping in mind the aforementioned limitation. We also can use the RMSE metric to optimize the parameters of each method separately and derive practical advice on how to tune them with respect to the image content

## Manual annotation.

We use Icy to annotate the image. To get and install Icy, follow the instructions here:

http://icy.bioimageanalysis.org/download/

Run it and open the 3D image you want to project. For the comparison, it must a single-channel, single-time-point 3D image.

You must now annotate the image by creating a single Area 2D ROI per z-slice, where you label the part of the slice where the cells of interest are in focus.

![Screenshot 2021-03-22 100043](docs\Screenshot 2021-03-22 100043.png)

Once it is done for one slice, rename the ROI with something like `z06` (not required, but helps finding problems for large images) and set the Z-position of the ROI to the current slice.  Then repeat for all z-slices.![Screenshot 2021-03-22 095939](docs\Screenshot 2021-03-22 095939.png)

Depending on the size of the image, this step can take a lot of time. The ROIs are saved automatically when you close the image, in a `XML` file with the same name that of the image. You can always pause and resuming the work. We have found that using a pen tablet accelerate the annotation process and alleviate a bit its tediousness. 

It is ok if for one (X, Y) position we have several ROIs across all the Z-values. The projection will take the max pixel value, and the height-map will average the Z positions of the ROIs taken into account. It is important however that all the pixels of the tissue are present in at least one ROI, lest your projection will have holes. Pixels without annotation can be detected in the ground truth height-map (see below for how to generate it) by checking what ones have a value equal to 0. Regions of the image without tissue will be marked separately with an ImageJ ROI and a mask (see below).

## Generating the projection and height-map image.

The Python script `GenerateGroundTruth.py` will generate the ground-truth projection and height-map from the ROIs.

In Icy, open the script editor and load the script. You will have to edit the line 15 to input the name of the image sequence.

![Screenshot 2021-03-22 100741](docs\Screenshot 2021-03-22 100741.png)

Run the script. You can ignore messages about Icy being unable to access some pixels.

It should generate the projection and the height-map, that you must save in this folder. These two files will be used later for comparing the different projection methods.

## Marking regions of the image without tissue.

We need also to mark what parts of the image contain the tissue and what part does not. We do this by creating an ImageJ ROI file that encompasses the tissue, and a mask image that has 0-value where there are no tissue. 

To do this, open the ground-truth height-map in Fiji.

- Using the threshold window, sets the threshold range to 0.5 - 5000 to select pixels with a value larger than 0.

![Screenshot 2021-03-22 102426](docs\Screenshot 2021-03-22 102426.png)

- Then run *Analyze > Analyze Particles* to generate a ROI around the tissue, that will be stored in the ROI Manager. Save this ROI as `ProjectionRoi.roi`.

![Screenshot 2021-03-22 102948](docs\Screenshot 2021-03-22 102948.png)

- Finally, create a mask from this ROI by using *Edit > Selection > Create  Mask* menu item. The resulting mask image should be an 8-bit image with white pixels (value = 255) within the tissue and black (value = 0) elsewhere. Save it as a tif file under the name `ProjectionMask.tif`.

![Screenshot 2021-03-22 141340](docs\Screenshot 2021-03-22 141340.png)



