# Running the Extended-Depth-Of-Field method on the test image.

## Getting the EDF plugin.

The Extended-Depth-Of-Field (EDF) method is offered as Fiji plugin, available by subscribing to a Fiji update site. In Fiji, go to the _Help > Update_ menu. In the Fiji updater, click on the `Manage update sites` button, and in the dialog that shows up, select the _BIG-EPFL_ site:

![Screenshot 2021-03-12 093943](docs\Screenshot 2021-03-12 093943.png)

Then restart Fiji.

The Extended-Depth-Of-Field is located in the _Plugins > Process_ menu of Fiji.

## Running EDF on the test image.

I made a Jython script to run the parameter sweep: _RunExtendedDepthOfField.py_. Drag and drop the file in the Fiji toolbar, and it will open in the Fiji editor. You have to edit the lines 30 to 44, so that they point to the source image (`source_image`), the ground truth image (`ground_truth`), the ROI (`roi`)  delimitating the tissue and where to save the results (`save_folder`).

![Screenshot 2021-03-12 095116](docs\Screenshot 2021-03-12 095116.png)

Then run the script. It will launch the EDF plugin testing 25 parameters (all the combination of the EDF plugin in the "easy" mode), measure the RMSE directly and save them to a CSV file in the `Results` folder.

## Plotting the RMSE values.

Check the MATLAB script `ComputeRMSE.m`. It is not properly named because it just reads the RMSE values in the CSV file mentioned above and plots them. Normally you don't have to edit it. It will generate a graph resembling this:

![RMSE](RMSE.png)

The parameter sets are organized in the X axis first by the Quality parameter in 5 columns from left to right:

    - Sobel
    - Variance
    - Real wavelets
    - Real wavelets with MCC
    - Complex wavelets with MCC
Then within one column, the Topology parameters are arranged from left to right (A to E) like this:

    - No smoothing
    - Median 3x3
    - Median 3x3 + Gaussian sigma=1
    - Median 3x3 + Gaussian sigma=2 + Closing
    - Median 5x5 + Gaussian sigma=4 + Opening + Closing
Check the associated articles for the details on these parameters:

B. Forster, D. Van De Ville, J. Berent, D. Sage, M. Unser, "[Complex Wavelets for Extended Depth-of-Field: A New Method for the Fusion of Multichannel Microscopy Images](http://bigwww.epfl.ch/publications/forster0404.html)," *Microsc. Res. Tech.*, **65**(1-2), pp. 33-42, September 2004.

F. Aguet, D. Van De Ville, and M. Unser "[Model-based 2.5-D deconvolution for extended depth-of-field in brightfield microscopy](http://bigwww.epfl.ch/publications/aguet0802.html)," *IEEE Trans. Image Process.*, **17**(7), pp. 1144-1153, July 2008.

## Timing the EDF plugin.

We do not want to have the timing metric altered by warm-up or just-in-time-compiler activities. So we defined the timing of a process as the median of 5 runs using the best parameter set identified by the previous script.

The timing of the EDF plugin is done separately with another script. Open the file _TimeExtendedDepthOfField.py_ in Fiji. As above, you have the edit some lines so that the path points to your test folders.

You also have to enter what is the optimal parameter set. In the example above, we have found that we achieved the best RMSE by using the _Variance_ parameter for the quality (2nd value so `quality=1`) and the _No smoothing_ value for the topology parameter (1st value of `topology=1`).

![Screenshot 2021-03-12 103354](docs\Screenshot 2021-03-12 103354.png)

Run the script. It will run the EDF plugin 5 times with the optimal parameters, and store the timing results in the _OptimalTimings.txt_ file in the _Results_ folder.

![Screenshot 2021-03-12 102738](docs\Screenshot 2021-03-12 102738.png)
