import os.path
import datetime
from net.imagej import Dataset
import time

from ij import IJ
from ij import WindowManager

from edf import Tools
from edfgui import Parameters
from edfgui import ExtendedDepthOfField


'''
Time the Extended Depth of Field plugin, taking the median of 5 runs with 
the best parameters (in the RMSE sense).
'''


#------------------
# Parameters.
#------------------

# 3D source image to project.
source_image = 'D:/Projects/DProj/DProjComparisonToolBox-02/Live-Notum-2018_03_08_cad_cic_LSM-C0T0.tif'

save_folder = 'D:/Projects/DProj/DProjComparisonToolBox-02/Methods/ExtendedDepthOfField/Results'

best_quality = 1
best_topology = 0

#------------------
# Run.
#------------------

imp = IJ.openImage( source_image )
imp.show()

# Store execution time.
timings = []
timings_file_path = os.path.join( save_folder, 'OptimalTimings.txt' )
with open( timings_file_path, 'w+' ) as f:
	f.write( 'Timing ExtendedDepthOfField with optimal parameters:'  )
	f.write( 'Started on %s\n' % datetime.datetime.now()  )

# Source image must be the active one.
imp = WindowManager.getCurrentImage();


print( '\n\n\n\n____________________________________' )
print( 'Starting. %s' % datetime.datetime.now() )
print( 'ExtendedDepthOfField tests.' )

for i in range(5):

	params = Parameters()
	params.showTopology = True
	params.setTopologySettings( best_topology )
	params.setQualitySettings( best_quality )
	params.color = False
	nScalesAndSize = Tools.computeScaleAndPowerTwoSize( imp.getWidth(), imp.getHeight() );
	nScales = nScalesAndSize[0]
	params.maxScales = nScales
	
	edf = ExtendedDepthOfField( imp, params )

	start = time.time()
	edf.process()
	end = time.time()
	
	deltaT = end - start
	timings.append( deltaT )

	# Close.
	out = WindowManager.getCurrentImage()
	out.close()

	# Save timings
	with open( timings_file_path, 'a' ) as f:
		f.write( "run %d: %s s.\n" % ( i, deltaT ) )

print( 'Finished! - %s' % datetime.datetime.now() )
