%% Compare ExtendedDepthOfField images with 'ground truth'.
% We analyze and plot a sweep on the 'easy mode' parameters.

clear
close all
clc

root_folder = './Results';

file_names = {
    'Live-Notum-2018_03_08_cad_cic_LSM-C0T0_SME_Projection_CH1_ref1_nCH1_above0_down0_CF.tif'
    'Live-Notum-2018_03_08_cad_cic_LSM-C0T0_SME_Projection_CH1_ref1_nCH1_above1_down1_CF.tif'
    'Live-Notum-2018_03_08_cad_cic_LSM-C0T0_SME_Projection_CH1_ref1_nCH1_above2_down2_CF.tif'
    'Live-Notum-2018_03_08_cad_cic_LSM-C0T0_SME_Projection_CH1_ref1_nCH1_above3_down3_CF.tif'
    'Live-Notum-2018_03_08_cad_cic_LSM-C0T0_SME_Projection_CH1_ref1_nCH1_above4_down4_CF.tif'
    'Live-Notum-2018_03_08_cad_cic_LSM-C0T0_SME_Projection_CH1_ref1_nCH1_above5_down5_CF.tif'
    };

strs = {
    '\Delta z = 0'
    '\Delta z = 1'
    '\Delta z = 2'
    '\Delta z = 3'
    '\Delta z = 4'
    '\Delta z = 5'
    };

timing_data = readtable( 'Results/Timings.txt' );
timings = timing_data.Timing_s;

%% Ground truth.

ground_truth_img_path = '../../GroundTruth/C0T0_GT_Proj.tif';
G = double( imread(ground_truth_img_path) );

mask_path =  '../../GroundTruth/ProjectionMask.tif';
M = logical ( imread( mask_path) );

%% Test images.

n_files = numel( file_names );
rmse        = NaN( n_files, 1 );

for i = 1 : n_files
  
    file_name = file_names{ i };
    I = double( imread( fullfile( root_folder, file_names{i} ) ) );
    rmse( i ) = sqrt( immse( G(M), I(M) ) );

end


%% Plot results.

close
figure

yyaxis left
hold on
set(gca, 'FontSize', 24, 'FontName', 'Arial')

y = rmse;
x = 1 : numel( y );

scatter( x, y, 200, 'o', 'Filled' );

% Determine best parameter.

[ best_RMSE, a ] = min( y );
best_parameter = x( a );
best_timing = timings( a );

yl = ylim();
ml1 = yl(1);
ml2 = yl(1) + (yl(2)-yl(1)) * 0.5;
xlim( [ 0.5 numel(x)+0.5 ] )

hb = line( [ best_parameter best_parameter ], [ ml1 ml2 ], ...
    'LineStyle', ':', ...
    'Color', 'k' );
text( best_parameter, ml2, ...
     { 'Optimal parameter set'
    sprintf('RMSE = %.1f,\nTiming = %.1f s', best_RMSE, best_timing ) }, ...
    'Color', 'k', ...
    'FontSize', 20, 'FontName', 'Arial')

xticks = 1 : numel(x);
set( gca, ... 
    'XTickLabels', strs, ...
    'XTick', xticks , ....
    'XTickLabelRotation', 45 )

xlabel('Parameters')
ylabel('RMSE')



% Plot timings.

yyaxis right
hold on
set(gca, 'FontSize', 24, 'FontName', 'Arial')

y2 = timings;
hs = scatter( x, y2, 200, 'o', 'Filled');
ylim( [ 10 20 ] )
ylabel('Execution time (s)')


export_fig 'RMSE.pdf'
