# Running the Local-Z-Projector method on the test image.

## Getting the LZP plugin.

The Local-Z-Projector (LZP) method is offered as Fiji plugin, available by subscribing to a Fiji update site. In Fiji, go to the _Help > Update_ menu. In the Fiji updater, click on the `Manage update sites` button, and in the dialog that shows up, select the _BIG-EPFL_ site:

![Screenshot 2021-03-12 104014](docs\Screenshot 2021-03-12 104014.png)

Then restart Fiji.

The Local-Z-Projector plugin is located in the _Plugins > Process_ menu of Fiji.

## Running LZP on the test image.

There are several Jython scripts to run the parameter sweep. The main one is _RunLocalZProjection_ALL.py_ and it runs the LZP plugin over a wide range of parameters. It can take quite some time to test a large image (several days if you want to be exhaustive). The other scripts are used  to check the influence of a single parameter. They are a simplified version of the _ALL_ script. You can run them if you want to determine an optimum for a single parameter.

Drag and drop the file in the Fiji toolbar, and it will open in the Fiji editor. You have to edit the lines 31to 45, so that they point to the source image (`source_image`), the ground truth image (`ground_truth`), the ROI (`roi`)  delimitating the tissue and where to save the results (`save_folder`).

![Screenshot 2021-03-12 105743](docs\Screenshot 2021-03-12 105743.png)

You also want to check the lines 81 to 84 where we define the parameters range we will test. For the paper we were very exhaustive and also tested unreasonable values that led to long computation time. In particular small binning values takes a very long time and are not that useful.

![Screenshot 2021-03-12 110017](docs\Screenshot 2021-03-12 110017.png)

Then run the script. It will run the plugin, measure the RMSE directly and save results to a CSV file in the `Results/SweepAll` folder.

## Import the RMSE values.

Check the MATLAB script _ImportSweepAllResults.m_. Normally you don't have to edit it. It will import the CSV file as a MATLAB table, resave it as Excel files (if you uncomment lines 14 and 33), and find the best parameters.

It also estimate a "good" parameter set, that runs the fastest but accept a RMSE value not larger than 0.1 plus the absolute best:

![Screenshot 2021-03-12 111532](docs\Screenshot 2021-03-12 111532.png)

## Timing the LZP plugin.

We do not want to have the timing metric altered by warm-up or just-in-time-compiler activities. So we defined the timing of a process as the median of 5 runs using the best parameter set identified by the previous script. There is a specific script to do so: _TimeLocalZProjection.py_

You need to edit the lines 28 to 38 to input the proper path to the source images, and the optimal parameter set found in the previous paragraph:

![Screenshot 2021-03-12 114418](docs\Screenshot 2021-03-12 114418.png)

Run the script. It will run the EDF plugin 5 times with the optimal parameters, and store the timing results in the _OptimalTimings.txt_ file in the _Results_ folder.

![Screenshot 2021-03-12 114450](docs\Screenshot 2021-03-12 114450.png)



It also saves the optimal projection and associated height-map, which we will use for the metrics on segmentation results and height-map.
