#@ OpService ops
#@ ConvertService convert
#@ DatasetService datasetService
#@ DatasetIOService io

import os.path
import datetime
from net.imagej import Dataset
from ij import IJ
from fr.pasteur.iah.localzprojector.process import LocalZProjectionOp
from fr.pasteur.iah.localzprojector.process import ReferenceSurfaceParameters
from fr.pasteur.iah.localzprojector.process.ReferenceSurfaceParameters import Method
from fr.pasteur.iah.localzprojector.process import ExtractSurfaceParameters
from fr.pasteur.iah.localzprojector.process.ExtractSurfaceParameters import ProjectionMethod
import time

'''
Time the Local Z Projectoion plugin, taking the median of 5 runs with 
the best parameters (in the RMSE sense).
'''



#------------------
# Parameters.
#------------------

# 3D source image to project.
source_image = 'D:/Projects/DProj/DProjComparisonToolBox-02/Live-Notum-2018_03_08_cad_cic_LSM-C0T0.tif'

# Where to save the results.
save_folder = 'D:/Projects/DProj/DProjComparisonToolBox-02/Methods/LocalZProjection/Results/SweepAll'

filterWindowSize 	= 45 	# Absolute best
binning 		 	= 2 	# Absolute best
deltaZ			  	= 1 	# Absolute best
medianFilterSize 	= 4 	# Absolute best
gaussianFilter   	= 0.33 	# Absolute best
# RMSE = 76.836

#filterWindowSize 	= 11 	# Good and fast
#binning 		 	= 7 	# Good and fast
#deltaZ			  	= 1 	# Good and fast
#medianFilterSize 	= 4 	# Good and fast
#gaussianFilter   	= 0.33 	# Good and fast
# RMSE = 76.923, 10 times faster


version = LocalZProjectionOp().getVersion()

# Store execution time.
timings = []
timings_file_path = os.path.join( save_folder, 'OptimalTimings.txt' )
with open( timings_file_path, 'w+' ) as f:
	f.write( 'LocalZProjection v%s timing for optimal parameters.\n' % version  )
	f.write( 'Started on %s\n' % datetime.datetime.now()  )


# What channel to use to create the reference surface?
channel = 0

# Load and convert the 3D image to project.
imp = IJ.openImage( source_image )
img = convert.convert( imp, Dataset )

print( '\n\n\n\n____________________________________' )
print( 'Starting. %s' % datetime.datetime.now() )
print( 'LocalZProjection plugin version: %s' % version )

for i in range( 5 ):

	# Reference surface parameters.
	params_ref_surface = ReferenceSurfaceParameters.create() \
					.method( Method.MAX_OF_STD ) \
					.zMin( 0 ) \
					.zMax( 100000 ) \
					.filterWindowSize( int( filterWindowSize ) ) \
					.binning( int( binning ) ) \
					.gaussianPreFilter( gaussianFilter ) \
					.medianPostFilterHalfSize( int( medianFilterSize ) ) \
					.targetChannel( channel ) \
					.get()
	
	# Local projection parameters.
	params_proj = ExtractSurfaceParameters.create() \
					.zOffset( 0, 0 ) \
					.deltaZ( 0, int( deltaZ ) ) \
					.projectionMethod( 0, ProjectionMethod.MIP ) \
					.get()
	
	
	#------------------
	# Execute.
	#------------------
	
	# Create op, specifying only input type and the two parameters.
	lzp_op = ops.op( LocalZProjectionOp, Dataset, params_ref_surface, params_proj )
	# Execute local Z projection.
	start = time.time()
	local_proj = lzp_op.calculate( img )
	end = time.time()
	deltaT = end - start
	timings.append( deltaT )
	
	# Save timings
	with open( timings_file_path, 'a' ) as f:
		f.write( "run %d: %s s.\n" % ( i, deltaT ) )

n = len( timings )
s = sorted( timings )
median = (sum(s[n//2-1:n//2+1])/2.0, s[n//2])[n % 2] if n else None

with open( timings_file_path, 'a' ) as f:
	f.write( "\nmedian = %s s.\n" % median )

# Save optimum.
file_name = 'OptimalLocalZProjection_fs%02d_ms%02d_gauss%4.2f_binning%1d_deltaZ%1d.tif' % ( filterWindowSize, medianFilterSize, gaussianFilter, binning, deltaZ )

file_path = os.path.join( save_folder, file_name )
local_proj_output = datasetService.create( local_proj )
local_proj_output.setName( file_name )
io.save( local_proj_output, file_path )

ref_surface = lzp_op.getReferenceSurface()
ref_surface_file_path = os.path.join( save_folder, 'RefSurface_' + file_name )
io.save( ref_surface, ref_surface_file_path )

print( 'Finished! - %s' % datetime.datetime.now() )
