%% Compare ExtendedDepthOfField images with 'ground truth'.
% We analyze and plot a sweep on the 'easy mode' parameters.

clear
close all
clc

root_folder = './Results';

file_names = {
    '1surface-rxy0.25-rz0.5-dz1.tif'
    '1surface-rxy0.25-rz0.5-dz2.tif'
    '1surface-rxy0.25-rz0.5-dz3.tif'
    '1surface-rxy0.25-rz0.5-dz4.tif'
    '1surface-rxy0.5-rz1-dz1.tif'
    '1surface-rxy0.5-rz1-dz2.tif'
    '1surface-rxy0.5-rz1-dz3.tif'
    '1surface-rxy0.5-rz1-dz4.tif'
    };

strs = {
    'R_{xy}=0.25 R_z=0.5 D_z=1'
    'R_{xy}=0.25 R_z=0.5 D_z=2'
    'R_{xy}=0.25 R_z=0.5 D_z=3'
    'R_{xy}=0.25 R_z=0.5 D_z=4'
    'R_{xy}=0.5 R_z=1 D_z=1'
    'R_{xy}=0.5 R_z=1 D_z=2'
    'R_{xy}=0.5 R_z=1 D_z=3'
    'R_{xy}=0.5 R_z=1 D_z=4'
    };

%% Ground truth.

ground_truth_img_path = '../../GroundTruth/C0T0_GT_Proj.tif';
G = double( imread(ground_truth_img_path) );

mask_path =  '../../GroundTruth/ProjectionMask.tif';
M = logical ( imread( mask_path) );

%% Test images.

n_files = numel( file_names );
rmse        = NaN( n_files, 1 );

for i = 1 : n_files
  
    file_name = file_names{ i };
    I = double( imread( fullfile( root_folder, file_names{i} ) ) );
    rmse( i ) = sqrt( immse( G(M), I(M) ) );

end


%% Plot results.

close
figure( 'Position', [ 681   328   787   651 ] )

hold on
set(gca, 'FontSize', 24, 'FontName', 'Arial')

y = rmse;
x = 1 : numel( y );

scatter( x, y, 200, 'o', 'Filled' );

% Determine best parameter.

[ best_RMSE, a ] = min( y );
best_parameter = x( a );

yl = ylim();
ml1 = yl(1);
ml2 = yl(1) + (yl(2)-yl(1)) * 0.5;
xlim( [ 0.5 numel(x)+0.5 ] )

hb = line( [ best_parameter best_parameter ], [ ml1 ml2 ], ...
    'LineStyle', ':', ...
    'Color', 'k' );
text( best_parameter, ml2, ...
     { 'Optimal parameter set'
    sprintf('RMSE = %.1f', best_RMSE ) }, ...
    'Color', 'k', ...
    'FontSize', 20, 'FontName', 'Arial')

xticks = 1 : numel(x);
set( gca, ... 
    'XTickLabels', strs, ...
    'XTick', xticks , ....
    'XTickLabelRotation', 45 )

xlabel('Parameters')
ylabel('RMSE')


export_fig 'RMSE.pdf'
