# Time Stack Focuser with optimal parameter.

import os.path
import datetime
import time

from ij import IJ
from ij import WindowManager



#------------------
# Parameters.
#------------------

# Where to save the results.
save_folder = 'D:/Projects/DProj/DProjComparisonToolBox-02/Methods/StackFocuser/Results'

filter_size = 19 # Optimum

# Store execution time.
timings = []
timings_file_path = os.path.join( save_folder, 'OptimalTimings.txt' )
with open( timings_file_path, 'w+' ) as f:
	f.write( 'StackFocuser'  )
	f.write( 'Started on %s\n' % datetime.datetime.now()  )
	
# Source image must be the active one.
imp = WindowManager.getCurrentImage();


print( '\n\n\n\n____________________________________' )
print( 'Starting. %s' % datetime.datetime.now() )
print( 'StackFocuser tests.' )

for i in range( 5 ):

	
	start = time.time()
	
	IJ.run( imp, "Stack Focuser ", "enter=" + str( filter_size ) );
	
	end = time.time()
	deltaT = end - start
	timings.append( deltaT )

	# Close 
	out = WindowManager.getCurrentImage()
	out.close()

	# Save timings
	with open( timings_file_path, 'a' ) as f:
		f.write( "run %d: %s s.\n" % ( i, deltaT ) )

n = len( timings )
s = sorted( timings )
median = (sum(s[n//2-1:n//2+1])/2.0, s[n//2])[n % 2] if n else None

with open( timings_file_path, 'a' ) as f:
	f.write( "\nmedian = %s s.\n" % median )

	
print( 'Finished! - %s' % datetime.datetime.now() )
