%% Compare SurfCut images with 'ground truth'.
% This comparison os trickier than others, for SurfCut only accepts 8-bit
% images. So we made a 8-bit version of the source image, the ground truth
% image, and compute from what we have then.

clear
close all
clc

root_folder = './Results';


file_names = {
    'SurfCutProjection_gaussradius0_threshold_80_dz0.tif'
    'SurfCutProjection_gaussradius1_threshold_80_dz0.tif'
    'SurfCutProjection_gaussradius10_threshold_80_dz0.tif'
    'SurfCutProjection_gaussradius2_threshold_80_dz0.tif'
    'SurfCutProjection_gaussradius3_threshold_200_dz0.tif'
    'SurfCutProjection_gaussradius3_threshold_50_dz0.tif'
    'SurfCutProjection_gaussradius3_threshold_80_dz0.tif'
    'SurfCutProjection_gaussradius3_threshold_80_dz1.tif'
    'SurfCutProjection_gaussradius3_threshold_80_dz2.tif'
    'SurfCutProjection_gaussradius30_threshold_80_dz0.tif'
    'SurfCutProjection_gaussradius5_threshold_80_dz0.tif'
    };

strs = {
    'radius=0, threshold=80, dz=0'
    'radius=1, threshold=80, dz=0'
    'radius=10, threshold=80, dz=0'
    'radius=2, threshold=80, dz=0'
    'radius=3, threshold=200, dz=0'
    'radius=3, threshold=50, dz=0'
    'radius=3, threshold=80, dz=0'
    'radius=3, threshold=80, dz=1'
    'radius=3, threshold=80, dz=2'
    'radius=30, threshold=80, dz=0'
    'radius=5, threshold=80, dz=0'
    };

%% Ground truth.

ground_truth_img_path = '../../GroundTruth/C0T0_GT_Proj.tif';
G = double( imread(ground_truth_img_path) );

mask_path =  '../../GroundTruth/ProjectionMask.tif';
M = logical ( imread( mask_path) );

%% Test images.

n_files = numel( file_names );
rmse        = NaN( n_files, 1 );

for i = 1 : n_files
  
    file_name = file_names{ i };
    I = double( imread( fullfile( root_folder, file_names{i} ) ) );
    rmse( i ) = sqrt( immse( G(M), I(M) ) );

end


%% Plot results.

close
figure( 'Position', [ 681   328   787   651 ] )

hold on
set(gca, 'FontSize', 24, 'FontName', 'Arial')

y = rmse;
x = 1 : numel( y );

scatter( x, y, 200, 'o', 'Filled' );

% Determine best parameter.

[ best_RMSE, a ] = min( y );
best_parameter = x( a );

yl = ylim();
ml1 = yl(1);
ml2 = yl(1) + (yl(2)-yl(1)) * 0.5;
xlim( [ 0.5 numel(x)+0.5 ] )

hb = line( [ best_parameter best_parameter ], [ ml1 ml2 ], ...
    'LineStyle', ':', ...
    'Color', 'k' );
text( best_parameter, ml2, ...
     { 'Optimal parameter set'
    sprintf('RMSE = %.1f', best_RMSE ) }, ...
    'Color', 'k', ...
    'FontSize', 20, 'FontName', 'Arial')

xticks = 1 : numel(x);
set( gca, ... 
    'XTickLabels', strs, ...
    'XTick', xticks , ....
    'XTickLabelRotation', 45 )

xlabel('Parameters')
ylabel('RMSE')


export_fig 'RMSE.pdf'
