%% Collate and plot all performance metrics, and generate a figure.

clear 
close all
clc

%% Data.

methods = {
    'on ground-truth'
    'M.I.P.'
    'LZP absolute best'
    'Stack Focuser'
    'SurfCut'
    'PreMosa'
    'E.D.F.'
    'Min Cost Z S.'
    'Fast SME'
    'LZP good second'
};


rmse_projection = [
     NaN % NA
     179.6 % MIP
     76.836 % Local Z Projector Absolute
     96.686496267 % Stack Focuser
     170.5 % SurfCut
     79.9 % PreMosa
     145.5 % E.D.F.
     138.4 % MinCostZSurface
     81.5 % Fast SME
     76.923 % Local Z Projector Good
    ];

rmse_heightmap = [
    NaN  % NA
    NaN  % NA MIP
    1.1784 % Local Z Projector Absolute
    71.1230 % Stack Focuser rescaled
    NaN % NA SurfCut
    1.3803 % PreMosa
    3.5906 % E.D.F.
    2.15236 % MinCostZSurface
    0.4881 % Fast SME
    1.0832 % Local Z Projector Good
    ];

oce_segmentation = [
    0.0232 % GT
    0.3497 % MIP
    0.0804 % Local Z Projector Absolute
    0.1412 % Stack Focuser
    0.5813 % SurfCut
    0.0992 % PreMosa
    0.2608 % EDF
    0.2897 % Min Cost Z Surface
    0.0776 % Fast SME
    0.0660 % Local Z Projector Good
    ];

time_units = 's';
timings = [
    NaN  % NA
    0.0469999313354 % MIP
    4.95899987221 % Local Z Projector
    5.1740000248 % Stack Focuser
    1.50 % SurfCut
    1.604222 % PreMosa
    6.91200017929 % E.D.F.
    8.70 % MinCostZSurface
    9.9856 % Fast SME
    0.352999925613 % Local Z Projector Good
    ];

%% Figure.

n = numel( methods );
x = 1 : n;
colors = brewermap( n-1, 'Pastel2');
% Copy back the color for Local-Z-Projector
colors = [ colors ; colors(3,:) ];
font_size = 12;

hf = figure( 'Position', [ 1000 50 600 900 ] );

% RMSE projections.
subplot( 4, 1, 1)

b = bar( x, rmse_projection, ...
    'LineWidth', 2, ...
    'FaceColor', 'flat' );
text( x, rmse_projection, num2str( rmse_projection, 3 ), ...
    'Vert', 'bottom',...
    'Horiz', 'center'); 
for i = 1 : n
    b.CData ( i, : ) = colors( i, : );
end
box off
set( gca, ... 
    'XTickLabel', '', ...
    'XTick', x( ~isnan(rmse_projection ) ) , ...
    'FontSize', font_size, ...
    'FontName', 'Arial' )
ylabel('RMSE projection')


% RMSE height maps.
subplot( 4, 1, 2)

b = bar( x, rmse_heightmap, ...
    'LineWidth', 2, ...
    'FaceColor', 'flat' );
text( x, rmse_heightmap, num2str( rmse_heightmap, 3 ), ...
    'Vert', 'bottom',...
    'Horiz', 'center'); 
for i = 1 : n
    b.CData ( i, : ) = colors( i, : );
end
box off
set( gca, ... 
    'XTickLabel', '', ...
    'XTick', x( ~isnan(rmse_heightmap ) ) , ...
    'FontSize', font_size, ...
    'FontName', 'Arial' )
ylabel('RMSE height-map')

ylim( [ 0 75 ] )
breakyaxis( [ 7 70 ] )


% Timing.
subplot( 4, 1, 3)

b = bar( x, timings, ...
    'LineWidth', 2, ...
    'FaceColor', 'flat' );
text( x, timings, num2str( timings, 3 ), ...
    'Vert', 'bottom',...
    'Horiz', 'center'); 
for i = 1 : n
    b.CData ( i, : ) = colors( i, : );
end
box off
set( gca, ... 
    'XTickLabel', '', ...
    'XTick', x( ~isnan(timings ) ), ...
    'FontSize', font_size, ...
    'FontName', 'Arial' )

ylabel('Timing (s)')
% ylim( [ 0 10 ] )

% OCE.
subplot( 4, 1, 4)

b = bar( x, oce_segmentation, ...
    'LineWidth', 2, ...
    'FaceColor', 'flat' );
text( x, oce_segmentation, num2str( oce_segmentation, 3 ), ...
    'Vert', 'bottom',...
    'Horiz', 'center'); 
for i = 1 : n
    b.CData ( i, : ) = colors( i, : );
end
box off
set( gca, ... 
    'XTickLabel', methods, ...
    'XTickLabelRotation', 90, ...
    'XTick', x , ...
    'FontSize', font_size, ...
    'FontName', 'Arial' )
ylabel('Segmentation OCE')
ylim( [ 0 0.7 ] )


export_fig('-r600', '-painters', 'PerformanceMetrics.pdf' )
