# Measuring the performance against  segmentation of cells.

The quality of a projection has only meaning in the light of a subsequent analysis. We chose to focus on cell segmentation, and measure here how good is the results of a simple but automatic segmentation pipeline against a ground truth. 

The following assumes we have a tissue image where the cell membranes are labeled, forming a manifold. We will base our simple segmentation pipeline on the excellent MorphoLibJ library in Fiji.

## Installing MorpholibJ.

In Fiji, go to *Help > Update*. Click *Manage update sites* and check the *IJPB-plugins*.

![Screenshot 2021-03-22 165547](docs\Screenshot 2021-03-22 165547.png)



## Preparing the segmentation ground-truth.

You first need to prepare the ground truth segmentation. The format we expect is a black and white image where the cell interior is white and their membrane is black. It is very important that the connectivity of the cell objects is the 4-connectivity, not an 8-connectivity. Such a segmentation image resembles the following:

![Screenshot 2021-03-22 163509](docs\Screenshot 2021-03-22 163509.png)

You can either say that the cell white objects have 4-connectivity, or that the membrane black objects have 8 connectivity. We insist because it is a common source of error for us:

- the cell objects must be white
- the membrane objects must be black
- and we want this connectivity (the membrane pixels can be connected by the pixel diagonals):

![8-connectivity](docs\8-connectivity.png)

- and **not** this one (the membrane pixels only move east west north and south):

![4-connectivity](docs\4-connectivity.png)

Generating this segmentation ground truth can take a long time, in particular for large images. We advise the following:

- Start from the ground truth projection.
- Run the segmentation pipeline on it. We will recall it later, but it consists of the following:
  - Median filter 3x3 (radius = 2 in ImageJ),
  - Gaussian blur = 0.7 pixels,
  - Morphological Segmentation (in the MorpholibJ library) with a tolerance that depends on the image (here, we use 120) and a 4-connectivity.
- Then manually correct for the errors by adding missing or removing spurious ridges between cells. We will use a segmentation metric that is not too sensitive about the cell contour moving by 1 or so pixels in radius. 
- This can be one in Fiji. We found it easier to correct for mistakes on a 2-channels image shown in `Composite` mode, with the first channel being the segmentation and the second one being the projection. Like in the following example:

![Screenshot 2021-03-22 170426](docs\Screenshot 2021-03-22 170426.png)

- A pen tablet alleviate the tediousness of the task.
- Keep in mind that the manually added black ridges must have the 8-connectivity above. To get a black ridge 8-connectivity from something else, you can use Fiji *Process > Binary > Skeletonize* command.

Once it is done, save the ground-truth segmentation in this folder under the file name `GT.tif`.

## Running the segmentation pipeline on all projections.

To generate the files for the comparison, you now have to run the segmentation pipeline on all the best projection from each method. The segmentation pipeline is the following:

- Median filter 3x3 (radius = 2 in ImageJ),
- Gaussian blur = 0.7 pixels,
- Morphological Segmentation (in the MorpholibJ library) with a tolerance that depends on the image (here, we use 120) and a 4-connectivity.

Do not edit the results, and save it directly as an image under the name `Segmentation_of_METHOD.tif`. See the MATLAB script for name suggestions.

Again, check that the results have the right connectivity and the right mask value (cells are white, membranes are black).

## Running the comparison.

Check the Supplementary Note 3 in the article to read about the segmentation metrics we use.

The measurement itself is made by the MATLAB script `ComputeOCE.m`. There are a couple of lines to edit:

- Line 15: check that the path to the ground truth segmentation is correct.
- Line 20 to 29: the segmentation result file names will be built by taking the methods name in this array and adding to `Segmentation_of_METHOD.tif`. Check that they are right.

Then run the script. It can take a long time to run. The results will be stored in the `oce` variable.



